Glossary — Signalbox 2 documentation

### Navigation

- index
- previous |
- Signalbox 2 documentation »

# Glossary

user
  definition
researcher
  a specific role within the system, researchers have broad rights to configure the system, add/remove users, and other manage data
twilio
  Third party service used to make automated telephone calls. See https://www.twilio.com

### Navigation

- index
- previous |
- Signalbox 2 documentation »